@@ -31,6 +31,7 @@
 #include "ephy-settings.h"
 #include "ephy-smaps.h"
 #include "ephy-snapshot-service.h"
+#include "ephy-vcs-version.h"
 #include "ephy-web-app-utils.h"
 
 #include <gio/gio.h>
@@ -270,7 +271,7 @@ ephy_about_handler_handle_about (EphyAboutHandler       *handler,
   char *version;
   GtkIconInfo *icon_info;
 
-  version = g_strdup_printf (_("Version %s"), VERSION);
+  version = g_strdup_printf (_("Version %s"), VCSVERSION);
 
   icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
                                           "org.gnome.Epiphany",
@@ -436,22 +437,7 @@ history_service_query_urls_cb (EphyHistoryService     *history,
                           "  <meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n"
                           "  <meta name=\"viewport\" content=\"width=device-width\">"
                           "  <link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">\n"
-                          "  <script>\n"
-                          "    document.onkeypress = function listenKeypress(event) {\n"
-                          "      // Remove from overview when Del is pressed\n"
-                          "      if (event.which == 127) {\n"
-                          "        var focused = document.activeElement;\n"
-                          "        if (focused.className == \"overview-item\") {\n"
-                          "          removeFromOverview(focused, event);\n"
-                          "        }\n"
-                          "      }\n"
-                          "    }\n"
-                          "    function removeFromOverview(elem, event) {\n"
-                          "      event.preventDefault();\n"
-                          "      elem.className +=\" overview-removed \";\n"
-                          "      window.webkit.messageHandlers.overview.postMessage(elem.href);\n"
-                          "    }\n"
-                          "  </script>\n"
+                          "  <script> </script>\n"
                           "</head>\n"
                           "<body>\n",
                           lang, lang,
@@ -467,7 +453,7 @@ history_service_query_urls_cb (EphyHistoryService     *history,
                                             128,
                                             0);
     g_string_append_printf (data_str,
-                            "  <div class=\"overview-empty\">\n"
+                            "  <div id=\"overview\" class=\"overview-empty\">\n"
                             "    <img src=\"file://%s\"/>\n"
                             "    <div><h1>%s</h1></div>\n"
                             "    <div><p>%s</p></div>\n"
@@ -497,7 +483,7 @@ history_service_query_urls_cb (EphyHistoryService     *history,
 
     g_string_append_printf (data_str,
                             "<a class=\"overview-item\" title=\"%s\" href=\"%s\">"
-                            "  <div class=\"overview-close-button\" onclick=\"removeFromOverview(this.parentNode, event)\" title=\"%s\">&#10006;</div>"
+                            "  <div class=\"overview-close-button\" title=\"%s\">&#10006;</div>"
                             "  <span class=\"overview-thumbnail\"%s></span>"
                             "  <span class=\"overview-title\">%s</span>"
                             "</a>",
