@@ -47,13 +47,8 @@
 #include <gtk/gtk.h>
 #include <stdlib.h>
 
-#if ENABLE_HTTPS_EVERYWHERE
-#include <httpseverywhere.h>
-#endif
-
 #define PAGE_SETUP_FILENAME "page-setup-gtk.ini"
 #define PRINT_SETTINGS_FILENAME "print-settings.ini"
-#define OVERVIEW_RELOAD_DELAY 500
 
 typedef struct {
   WebKitWebContext *web_context;
@@ -67,8 +62,6 @@ typedef struct {
   EphyDownloadsManager *downloads_manager;
   EphyPermissionsManager *permissions_manager;
   EphyAboutHandler *about_handler;
-  guint update_overview_timeout_id;
-  guint hiding_overview_item;
   GDBusServer *dbus_server;
   GList *web_extensions;
   EphyFiltersManager *filters_manager;
@@ -103,7 +96,7 @@ static EphyEmbedShell *embed_shell = NULL;
 
 static void ephy_embed_shell_tabs_catalog_iface_init (EphyTabsCatalogInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (EphyEmbedShell, ephy_embed_shell, GTK_TYPE_APPLICATION,
+G_DEFINE_TYPE_WITH_CODE (EphyEmbedShell, ephy_embed_shell, DZL_TYPE_APPLICATION,
                          G_ADD_PRIVATE (EphyEmbedShell)
                          G_IMPLEMENT_INTERFACE (EPHY_TYPE_TABS_CATALOG,
                                                 ephy_embed_shell_tabs_catalog_iface_init))
@@ -163,11 +156,6 @@ ephy_embed_shell_dispose (GObject *object)
     g_clear_object (&priv->cancellable);
   }
 
-  if (priv->update_overview_timeout_id > 0) {
-    g_source_remove (priv->update_overview_timeout_id);
-    priv->update_overview_timeout_id = 0;
-  }
-
   g_clear_object (&priv->encodings);
   g_clear_object (&priv->page_setup);
   g_clear_object (&priv->print_settings);
@@ -207,7 +195,7 @@ web_extension_form_auth_data_message_received_cb (WebKitUserContentManager *mana
   GVariant *variant;
   gchar *message_str;
 
-  message_str = ephy_embed_utils_get_js_result_as_string (message);
+  message_str = jsc_value_to_string (webkit_javascript_result_get_js_value (message));
   variant = g_variant_parse (G_VARIANT_TYPE ("(utss)"), message_str, NULL, NULL, NULL);
   g_free (message_str);
 
@@ -227,7 +215,7 @@ web_extension_sensitive_form_focused_message_received_cb (WebKitUserContentManag
   GVariant *variant;
   char *message_str;
 
-  message_str = ephy_embed_utils_get_js_result_as_string (message);
+  message_str = jsc_value_to_string (webkit_javascript_result_get_js_value (message));
   variant = g_variant_parse (G_VARIANT_TYPE ("(tb)"), message_str, NULL, NULL, NULL);
   g_free (message_str);
 
@@ -279,37 +267,15 @@ history_service_urls_visited_cb (EphyHistoryService *history,
   ephy_embed_shell_update_overview_urls (shell);
 }
 
-static gboolean
-ephy_embed_shell_update_overview_timeout_cb (EphyEmbedShell *shell)
-{
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-
-  priv->update_overview_timeout_id = 0;
-
-  if (priv->hiding_overview_item > 0)
-    return FALSE;
-
-  ephy_embed_shell_update_overview_urls (shell);
-
-  return FALSE;
-}
-
 static void
 history_set_url_hidden_cb (EphyHistoryService *service,
                            gboolean            success,
                            gpointer            result_data,
                            EphyEmbedShell     *shell)
 {
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-
-  priv->hiding_overview_item--;
-
   if (!success)
     return;
 
-  if (priv->update_overview_timeout_id > 0)
-    return;
-
   ephy_embed_shell_update_overview_urls (shell);
 }
 
@@ -321,21 +287,13 @@ web_extension_overview_message_received_cb (WebKitUserContentManager *manager,
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   char *url_to_remove;
 
-  url_to_remove = ephy_embed_utils_get_js_result_as_string (message);
+  url_to_remove = jsc_value_to_string (webkit_javascript_result_get_js_value (message));
 
-  priv->hiding_overview_item++;
   ephy_history_service_set_url_hidden (priv->global_history_service,
                                        url_to_remove, TRUE, NULL,
                                        (EphyHistoryJobCallback)history_set_url_hidden_cb,
                                        shell);
   g_free (url_to_remove);
-
-  if (priv->update_overview_timeout_id > 0)
-    g_source_remove (priv->update_overview_timeout_id);
-
-  /* Wait for the CSS animations to finish before refreshing */
-  priv->update_overview_timeout_id =
-    g_timeout_add (OVERVIEW_RELOAD_DELAY, (GSourceFunc)ephy_embed_shell_update_overview_timeout_cb, shell);
 }
 
 static void
@@ -345,7 +303,7 @@ web_extension_tls_error_page_message_received_cb (WebKitUserContentManager *mana
 {
   guint64 page_id;
 
-  page_id = ephy_embed_utils_get_js_result_as_number (message);
+  page_id = jsc_value_to_double (webkit_javascript_result_get_js_value (message));
   g_signal_emit (shell, signals[ALLOW_TLS_CERTIFICATE], 0, page_id);
 }
 
@@ -356,7 +314,7 @@ web_extension_unsafe_browsing_error_page_message_received_cb (WebKitUserContentM
 {
   guint64 page_id;
 
-  page_id = ephy_embed_utils_get_js_result_as_number (message);
+  page_id = jsc_value_to_double (webkit_javascript_result_get_js_value (message));
   g_signal_emit (shell, signals[ALLOW_UNSAFE_BROWSING], 0, page_id);
 }
 
@@ -367,7 +325,7 @@ web_extension_about_apps_message_received_cb (WebKitUserContentManager *manager,
 {
   char *app_id;
 
-  app_id = ephy_embed_utils_get_js_result_as_string (message);
+  app_id = jsc_value_to_string (webkit_javascript_result_get_js_value (message));
   ephy_web_application_delete (app_id);
   g_free (app_id);
 }
@@ -747,7 +705,11 @@ initialize_web_extensions (WebKitWebContext *web_context,
   gboolean browser_mode;
   const char *address;
 
+#if DEVELOPER_MODE
+  webkit_web_context_set_web_extensions_directory (web_context, BUILD_ROOT "/embed/web-extension");
+#else
   webkit_web_context_set_web_extensions_directory (web_context, EPHY_WEB_EXTENSIONS_DIR);
+#endif
 
   address = priv->dbus_server ? g_dbus_server_get_client_address (priv->dbus_server) : NULL;
 
@@ -913,26 +875,6 @@ ephy_embed_shell_create_web_context (EphyEmbedShell *shell)
   g_object_unref (manager);
 }
 
-#if ENABLE_HTTPS_EVERYWHERE
-static void
-https_everywhere_update_cb (HTTPSEverywhereUpdater *updater,
-                            GAsyncResult           *result)
-{
-  GError *error = NULL;
-
-  https_everywhere_updater_update_finish (updater, result, &error);
-
-  if (!error)
-    return;
-
-  if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED) &&
-      !g_error_matches (error, HTTPS_EVERYWHERE_UPDATE_ERROR, HTTPS_EVERYWHERE_UPDATE_ERROR_IN_PROGRESS) &&
-      !g_error_matches (error, HTTPS_EVERYWHERE_UPDATE_ERROR, HTTPS_EVERYWHERE_UPDATE_ERROR_NO_UPDATE_AVAILABLE))
-    g_warning ("Failed to update HTTPS Everywhere rulesets: %s", error->message);
-  g_error_free (error);
-}
-#endif
-
 static char *
 adblock_filters_dir (EphyEmbedShell *shell)
 {
@@ -960,10 +902,6 @@ ephy_embed_shell_startup (GApplication *application)
   char *filename;
   char *cookie_policy;
   char *filters_dir;
-#if ENABLE_HTTPS_EVERYWHERE
-  HTTPSEverywhereContext *context;
-  HTTPSEverywhereUpdater *updater;
-#endif
 
   G_APPLICATION_CLASS (ephy_embed_shell_parent_class)->startup (application);
 
@@ -1071,24 +1009,6 @@ ephy_embed_shell_startup (GApplication *application)
   filters_dir = adblock_filters_dir (shell);
   priv->filters_manager = ephy_filters_manager_new (filters_dir);
   g_free (filters_dir);
-
-#if ENABLE_HTTPS_EVERYWHERE
-    /* We might want to be smarter about this in the future. For now,
-     * trigger an update of the rulesets once each time Epiphany is started.
-     * Note that the updated rules will not be used until the next time Epiphany
-     * is started. */
-  if (priv->mode != EPHY_EMBED_SHELL_MODE_TEST &&
-      priv->mode != EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER) {
-    context = https_everywhere_context_new ();
-    updater = https_everywhere_updater_new (context);
-    https_everywhere_updater_update (updater,
-                                     priv->cancellable,
-                                     (GAsyncReadyCallback)https_everywhere_update_cb,
-                                     NULL);
-    g_object_unref (context);
-    g_object_unref (updater);
-  }
-#endif
 }
 
 static void
