@@ -25,11 +25,12 @@
 #include "ephy-embed-utils.h"
 
 #include "ephy-about-handler.h"
+#include "ephy-prefs.h"
 #include "ephy-settings.h"
 #include "ephy-string.h"
 
-#include <JavaScriptCore/JavaScript.h>
 #include <glib/gi18n.h>
+#include <jsc/jsc.h>
 #include <libsoup/soup.h>
 #include <string.h>
 
@@ -126,6 +127,7 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
                      g_ascii_strncasecmp (address, "file", colonpos) &&
                      g_ascii_strncasecmp (address, "javascript", colonpos) &&
                      g_ascii_strncasecmp (address, "data", colonpos) &&
+                     g_ascii_strncasecmp (address, "blob", colonpos) &&
                      g_ascii_strncasecmp (address, "about", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-about", colonpos) &&
                      g_ascii_strncasecmp (address, "gopher", colonpos) &&
@@ -275,6 +277,9 @@ ephy_embed_utils_autosearch_address (const char *search_key)
   EphyEmbedShell *shell;
   EphySearchEngineManager *search_engine_manager;
 
+  if (!g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ENABLE_AUTOSEARCH))
+    return g_strdup (search_key);
+
   shell = ephy_embed_shell_get_default ();
   search_engine_manager = ephy_embed_shell_get_search_engine_manager (shell);
   address_search = ephy_search_engine_manager_get_default_search_address (search_engine_manager);
@@ -369,38 +374,6 @@ ephy_embed_utils_urls_have_same_origin (const char *a_url,
   return retval;
 }
 
-char *
-ephy_embed_utils_get_js_result_as_string (WebKitJavascriptResult *js_result)
-{
-  JSValueRef js_value;
-  JSStringRef js_string;
-  size_t max_size;
-  char *retval = NULL;
-
-  js_value = webkit_javascript_result_get_value (js_result);
-  js_string = JSValueToStringCopy (webkit_javascript_result_get_global_context (js_result),
-                                   js_value, NULL);
-  max_size = JSStringGetMaximumUTF8CStringSize (js_string);
-  if (max_size) {
-    retval = g_malloc (max_size);
-    JSStringGetUTF8CString (js_string, retval, max_size);
-  }
-  JSStringRelease (js_string);
-
-  return retval;
-}
-
-double
-ephy_embed_utils_get_js_result_as_number (WebKitJavascriptResult *js_result)
-{
-  JSValueRef js_value;
-
-  js_value = webkit_javascript_result_get_value (js_result);
-
-  return JSValueToNumber (webkit_javascript_result_get_global_context (js_result),
-                          js_value, NULL);
-}
-
 void
 ephy_embed_utils_shutdown (void)
 {
